"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _clone = _interopRequireDefault(require("clone"));

var _traverse = require("../utils/traverse");

var _jsx = require("../utils/jsx");

var _transform = require("../utils/transform");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Build the rawSrc attribute
 *
 * @param {Babel['types']} types
 * @param {CallExpression['arguments']} requireArgs
 * @returns {JSXAttribute}
 */
const buildRawSrcAttribute = (types, requireArgs) => {
  return types.jsxAttribute(types.jsxIdentifier('rawSrc'), types.jsxExpressionContainer((0, _transform.buildRequireStatement)(types, (0, _clone.default)(requireArgs), {
    include: ''
  })));
};
/**
 * Adds ?include query param to the rawSrc attribute of the Svg component
 */


const transformSvgComponent = (types, path) => {
  // abort if it has already the rawSrc attribute
  if ((0, _jsx.getAttribute)(path, 'rawSrc')) {
    return;
  }

  const src = (0, _jsx.getAttribute)(path, 'src');
  const requireArgs = src ? (0, _traverse.getRequireArguments)(types, src) : undefined;

  if (!src || !requireArgs) {
    return;
  }

  const rawSrc = buildRawSrcAttribute(types, requireArgs);
  path.get('openingElement').pushContainer('attributes', rawSrc);
  src.remove();
};

var _default = transformSvgComponent;
exports.default = _default;